Index: lib/Bitcode/NaCl/Writer/NaClValueEnumerator.h |
diff --git a/lib/Bitcode/Writer/ValueEnumerator.h b/lib/Bitcode/NaCl/Writer/NaClValueEnumerator.h |
similarity index 87% |
copy from lib/Bitcode/Writer/ValueEnumerator.h |
copy to lib/Bitcode/NaCl/Writer/NaClValueEnumerator.h |
index 0af6164c944f83b0f20ea0e5595392b0cd9a8e6b..9e9954883a61406ab6a946e552bf6ab93aed6a56 100644 |
--- a/lib/Bitcode/Writer/ValueEnumerator.h |
+++ b/lib/Bitcode/NaCl/Writer/NaClValueEnumerator.h |
@@ -1,4 +1,5 @@ |
-//===-- Bitcode/Writer/ValueEnumerator.h - Number values --------*- C++ -*-===// |
+//===-- Bitcode/NaCl/Writer/NaClValueEnumerator.h - ----------*- C++ -*-===// |
+// Number values. |
// |
// The LLVM Compiler Infrastructure |
// |
@@ -11,8 +12,8 @@ |
// |
//===----------------------------------------------------------------------===// |
-#ifndef VALUE_ENUMERATOR_H |
-#define VALUE_ENUMERATOR_H |
+#ifndef NACL_VALUE_ENUMERATOR_H |
+#define NACL_VALUE_ENUMERATOR_H |
#include "llvm/ADT/DenseMap.h" |
#include "llvm/ADT/SmallVector.h" |
@@ -34,7 +35,7 @@ class ValueSymbolTable; |
class MDSymbolTable; |
class raw_ostream; |
-class ValueEnumerator { |
+class NaClValueEnumerator { |
public: |
typedef std::vector<Type*> TypeList; |
@@ -83,10 +84,10 @@ private: |
unsigned FirstFuncConstantID; |
unsigned FirstInstID; |
- ValueEnumerator(const ValueEnumerator &) LLVM_DELETED_FUNCTION; |
- void operator=(const ValueEnumerator &) LLVM_DELETED_FUNCTION; |
+ NaClValueEnumerator(const NaClValueEnumerator &) LLVM_DELETED_FUNCTION; |
+ void operator=(const NaClValueEnumerator &) LLVM_DELETED_FUNCTION; |
public: |
- ValueEnumerator(const Module *M); |
+ NaClValueEnumerator(const Module *M); |
void dump() const; |
void print(raw_ostream &OS, const ValueMapType &Map, const char *Name) const; |
@@ -95,7 +96,7 @@ public: |
unsigned getTypeID(Type *T) const { |
TypeMapType::const_iterator I = TypeMap.find(T); |
- assert(I != TypeMap.end() && "Type not in ValueEnumerator!"); |
+ assert(I != TypeMap.end() && "Type not in NaClValueEnumerator!"); |
return I->second-1; |
} |
@@ -105,14 +106,14 @@ public: |
unsigned getAttributeID(AttributeSet PAL) const { |
if (PAL.isEmpty()) return 0; // Null maps to zero. |
AttributeMapType::const_iterator I = AttributeMap.find(PAL); |
- assert(I != AttributeMap.end() && "Attribute not in ValueEnumerator!"); |
+ assert(I != AttributeMap.end() && "Attribute not in NaClValueEnumerator!"); |
return I->second; |
} |
unsigned getAttributeGroupID(AttributeSet PAL) const { |
if (PAL.isEmpty()) return 0; // Null maps to zero. |
AttributeGroupMapType::const_iterator I = AttributeGroupMap.find(PAL); |
- assert(I != AttributeGroupMap.end() && "Attribute not in ValueEnumerator!"); |
+ assert(I != AttributeGroupMap.end() && "Attribute not in NaClValueEnumerator!"); |
return I->second; |
} |
@@ -145,7 +146,7 @@ public: |
unsigned getGlobalBasicBlockID(const BasicBlock *BB) const; |
/// incorporateFunction/purgeFunction - If you'd like to deal with a function, |
/// use these two methods to get its data into the ValueEnumerator! |
/// |
void incorporateFunction(const Function &F); |
void purgeFunction(); |
@@ -145,7 +146,7 @@ public: |
unsigned getGlobalBasicBlockID(const BasicBlock *BB) const; |
/// incorporateFunction/purgeFunction - If you'd like to deal with a function, |
- /// use these two methods to get its data into the ValueEnumerator! |
+ /// use these two methods to get its data into the NaClValueEnumerator! |
/// |
void incorporateFunction(const Function &F); |